@@ -5,7 +5,6 @@ pub mod parser_helpers;
 mod collections;
 mod print;
 mod print_items;
-mod print_write_items;
 mod printer;
 #[cfg(feature = "tracing")]
 mod tracing;
@@ -15,12 +14,15 @@ mod writer;
 pub mod tokens;
 pub mod utils;
 
-pub use print::{format, print, PrintOptions};
+pub use print::format;
+pub use print::print;
 #[cfg(feature = "tracing")]
-pub use print::{trace_printing, TracingResult};
+pub use print::trace_printing;
+pub use print::PrintOptions;
+#[cfg(feature = "tracing")]
+pub use print::TracingResult;
 pub use print_items::*;
-use print_write_items::*;
 use printer::*;
 #[cfg(feature = "tracing")]
 use tracing::*;
-pub use write_items::*;
+use write_items::*;
